@@ -5,7 +5,9 @@
 #' @template return
 #' @examples \dontrun{
 #' # Create a CouchDB connection client
-#' (x <- Cushion$new())
+#' user <- Sys.getenv("COUCHDB_TEST_USER")
+#' pwd <- Sys.getenv("COUCHDB_TEST_PWD")
+#' (x <- Cushion$new(user=user, pwd=pwd))
 #'
 #' session(x)
 #' session(x, as = 'json')
@@ -13,5 +15,6 @@
 session <- function(cushion, as = 'list', ...) {
   check_cushion(cushion)
   sofa_GET(file.path(cushion$make_url(), '_session'),
-           as = as, cushion$get_headers(), cushion$get_auth(), ...)
+    as = as, headers = cushion$get_headers(),
+    auth = cushion$get_auth(), ...)
 }
