@@ -42,7 +42,7 @@ sofa_GET <- function(url, as = 'list', query = NULL, headers = NULL,
                      auth = NULL, disk = NULL, ...) {
   as <- match.arg(as, c('list', 'json', 'raw'))
   cli <- crul::HttpClient$new(url = url,
-                              headers = c(ct_json, headers),
+                              headers = c(ct_json, a_json, headers),
                               opts = sc(c(auth, list(...))))
   res <- cli$get(query = query)
   stop_status(res)
@@ -54,7 +54,7 @@ sofa_GET_disk <- function(url, as = 'list', query = NULL, headers = NULL,
                      auth = NULL, disk, ...) {
   as <- match.arg(as, c('list', 'json', 'raw'))
   cli <- crul::HttpClient$new(url = url,
-                              headers = c(ct_json, headers),
+                              headers = c(ct_json, a_json, headers),
                               opts = sc(c(auth, list(...))))
   res <- cli$get(query = query, disk = disk)
   stop_status(res)
@@ -63,7 +63,7 @@ sofa_GET_disk <- function(url, as = 'list', query = NULL, headers = NULL,
 
 sofa_HEAD <- function(url, headers = NULL, auth = NULL, ...) {
   cli <- crul::HttpClient$new(url = url,
-                              headers = c(ct_json, headers),
+                              headers = c(ct_json, a_json, headers),
                               opts = sc(c(auth, list(...))))
   res <- cli$head()
   stop_status(res)
@@ -86,7 +86,7 @@ sofa_PUT <- function(url, as = 'list', body = NULL,
 
   as <- match.arg(as, c('list','json'))
   cli <- crul::HttpClient$new(
-    url = url, headers = c(ct_json, headers),
+    url = url, headers = c(ct_json, a_json, headers),
     opts = sc(c(auth, list(...))))
   res <- cli$put(body = body, encode = encode)
   stop_status(res)
@@ -97,7 +97,7 @@ sofa_PUT <- function(url, as = 'list', body = NULL,
 sofa_POST <- function(url, as = 'list', body, encode, headers = NULL,
                       auth = NULL, query = NULL, ...) {
   cli <- crul::HttpClient$new(url = url,
-                              headers = c(ct_json, headers),
+                              headers = c(ct_json, a_json, headers),
                               opts = sc(c(auth, list(...))))
   res <- cli$post(body = body, query = query, encode = encode)
   stop_status(res)
@@ -125,6 +125,8 @@ stop_status <- function(x) {
   }
 }
 
+`%||%` <- function(x, y) if (is.null(x)) y else x
+
 check_inputs <- function(x){
   if (length(x) == 0) {
     NULL
@@ -142,7 +144,7 @@ check_inputs <- function(x){
         x
       }
     } else if (is.list(x)) {
-      jsonlite::toJSON(x, auto_unbox = TRUE)
+      jsonlite::toJSON(x, auto_unbox = TRUE, digits = getOption("digits") %||% 7)
     } else {
       stop("Only character and list types supported currently")
     }
@@ -152,5 +154,14 @@ check_inputs <- function(x){
 check_if <- function(x, class) {
   if (!inherits(x, class)) stop("input must be of class ", class, call. = FALSE)
 }
+assert <- function(x, y) {
+  if (!is.null(x)) {
+    if (!inherits(x, y)) {
+      stop(deparse(substitute(x)), " must be of class ",
+          paste0(y, collapse = ", "), call. = FALSE)
+    }
+  }
+}
 
 ct_json <- list(`Content-Type` = "application/json")
+a_json <- list(Accept = "application/json")
